pub struct PingStore { /* private fields */ }Expand description
Data structure to store the latest pings sent to remote
Implementations
Sourceimpl PingStore
impl PingStore
pub fn new() -> Self
Sourcepub fn push_new(&mut self, now: Instant) -> PingId
pub fn push_new(&mut self, now: Instant) -> PingId
Pushes a new ping into the store and returns the corresponding ping id
Sourcepub fn remove(&mut self, ping_id: PingId) -> Option<Instant>
pub fn remove(&mut self, ping_id: PingId) -> Option<Instant>
Remove a ping from the store and returns the corresponding time if it exists
pub fn reset(&mut self)